@@ -7,7 +7,7 @@ Attean::TermMap - Mapping terms to new terms
 
 =head1 VERSION
 
-This document describes Attean::TermMap version 0.027
+This document describes Attean::TermMap version 0.028
 
 =head1 SYNOPSIS
 
@@ -42,11 +42,11 @@ term objects.
 
 =cut
 
-package Attean::TermMap 0.027 {
+package Attean::TermMap 0.028 {
 	use Moo;
 	use Types::Standard qw(CodeRef);
 	use Attean::API::Binding;
-	use Data::UUID;
+	use UUID::Tiny ':std';
 	use namespace::clean;
 	
 	with 'Attean::Mapper';
@@ -99,8 +99,8 @@ Returns a new L<Attean::TermMap> that renames blank nodes with UUID values.
 			my $id		= $term->value;
 			return $map{$id} if (defined($map{$id}));
 			
-			my $uuid	= Data::UUID->new->create_hex;
-			my $new		= Attean::Blank->new( $uuid );
+			my $uuid	= unpack('H*', create_uuid());
+			my $new		= Attean::Blank->new( 'b' . $uuid );
 			$map{$id}	= $new;
 			return $new;
 		});
