@@ -7,7 +7,7 @@ AtteanX::Parser::SPARQLLex - SPARQL Lexer
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLLex version 0.027
+This document describes AtteanX::Parser::SPARQLLex version 0.028
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ This document describes AtteanX::Parser::SPARQLLex version 0.027
 
 =cut
 
-package AtteanX::Parser::SPARQLLex 0.027 {
+package AtteanX::Parser::SPARQLLex 0.028 {
 	use utf8;
 	use Moo;
 	use Attean;
@@ -104,7 +104,7 @@ the SPARQL query/update read from the L<IO::Handle> object C<< $fh >>.
 	}
 }
 
-package AtteanX::Parser::SPARQLLex::Iterator 0.027 {
+package AtteanX::Parser::SPARQLLex::Iterator 0.028 {
 	use utf8;
 	use Moo;
 	use Attean;
@@ -224,8 +224,17 @@ package AtteanX::Parser::SPARQLLex::Iterator 0.027 {
 		unless (length($self->buffer)) {
 			my $line	= $self->file->getline;
 			if (defined($line)) {
-				$line		=~ s/\\u([0-9A-Fa-f]{4})/chr(hex($1))/ge;
-				$line		=~ s/\\U([0-9A-Fa-f]{8})/chr(hex($1))/ge;
+				no warnings 'uninitialized';
+				$line		=~ s{\\(?:(?:u([0-9A-Fa-f]{4}))|(?:U([0-9A-Fa-f]{8})))}{
+					my $h			= $1 . $2;
+					my $codepoint	= hex($h);
+					if ($codepoint >= 0xD800 and $codepoint <= 0xDFFF) {
+						die "Unicode surrogate U+$h is illegal in UTF-8";
+					}
+					chr($codepoint);
+				}ge;
+# 				$line		=~ s/\\u([0-9A-Fa-f]{4})/chr(hex($1))/ge;
+# 				$line		=~ s/\\U([0-9A-Fa-f]{8})/chr(hex($1))/ge;
 				$self->{buffer}	.= $line;
 			}
 		}
